pub fn get_field<T: FromLedger, const CODE: i32>(
_: SField<T, CODE>,
) -> Result<T>Expand description
Retrieves a field from the current ledger object using an SField constant.
Returns
Returns a Result<T> where:
Ok(T)- The field value for the specified fieldErr(Error)- If the field cannot be retrieved, has unexpected size, or fails to decode